@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 #--------------------------------------------------------------------------
 
@@ -37,8 +37,8 @@ use WWW::Mechanize;
 ###########################################################################
 # Constants
 
-use constant	REFERER	=> 'http://bookshop.blackwell.co.uk';
-use constant	SEARCH	=> 'http://bookshop.blackwell.co.uk/jsp/search_results.jsp?wcp=1&quicksearch=1&cntType=&searchType=keywords&searchData=%s&x=10&y=10';
+use constant REFERER => 'http://bookshop.blackwell.co.uk';
+use constant SEARCH  => 'http://bookshop.blackwell.co.uk/jsp/search_results.jsp?wcp=1&quicksearch=1&cntType=&searchType=keywords&searchData=%s&x=10&y=10';
 
 #--------------------------------------------------------------------------
 
@@ -82,10 +82,10 @@ The book_link, image_link and thumb_link all refer back to the Blackwell website
 =cut
 
 sub search {
-	my $self = shift;
-	my $isbn = shift;
-	$self->found(0);
-	$self->book(undef);
+    my $self = shift;
+    my $isbn = shift;
+    $self->found(0);
+    $self->book(undef);
 
     # validate and convert into EAN13 format
     my $ean = $self->convert_to_ean13($isbn);
@@ -94,7 +94,7 @@ sub search {
                  || (length $isbn == 10 && $isbn ne $self->convert_to_isbn10($ean)));
     my $isbn10 = $self->convert_to_isbn10($ean);
 
-	my $mech = WWW::Mechanize->new();
+    my $mech = WWW::Mechanize->new();
     $mech->agent_alias( 'Windows IE 6' );
     $mech->add_header( 'Accept-Encoding' => undef );
 
@@ -103,45 +103,46 @@ sub search {
 
     eval { $mech->get( $search ) };
     return $self->handler("Blackwell's website appears to be unavailable.")
-	    if($@ || !$mech->success() || !$mech->content());
+        if($@ || !$mech->success() || !$mech->content());
 
-	# The Book page
+    # The Book page
     my $html = $mech->content();
 
-	return $self->handler("Failed to find that book on the Blackwell website. [$isbn]")
-		if($html =~ m!Sorry, there are no results for!si);
+    return $self->handler("Failed to find that book on the Blackwell website. [$isbn]")
+        if($html =~ m!Sorry, there are no results for!si);
     
     $html =~ s/&amp;/&/g;
     $html =~ s/&nbsp;/ /g;
 #print STDERR "\n# html=[\n$html\n]\n";
 
     my $data;
-    ($data->{isbn13})       = $html =~ m!<meta property="book:isbn"\s+content="(\d+)"\s+/>!si;
-    ($data->{title})        = $html =~ m!<meta property="og:title"\s+content="([^"]+)"\s+/>!si;
-    ($data->{author})       = $html =~ m!<p class="product__author">\s*<a[^>]+>([^<]+)</a>!si;
-    ($data->{binding})      = $html =~ m!<p class="product__format">\s*<span itemprop="bookFormat" >([^<\(]+)!si;
-    ($data->{publisher})    = $html =~ m!<td>Publisher:</td>\s*<td itemprop="publisher">\s*<a[^>]+>([^<]+)</a>!si;
-    ($data->{pubdate})      = $html =~ m!<td>Pub date:</td>\s*<td itemprop="datePublished" content="([^"]+)">!si;
-    ($data->{description})  = $html =~ m!<meta property="og:description"\s+content="([^"]+)"\s+/>!si;
-    ($data->{pages})        = $html =~ m!<td>Number of pages:</td>\s*<td itemprop="numberOfPages">(\d+)</td>!si;
-    ($data->{weight})       = $html =~ m!<td>Weight:</td>\s*<td itemprop="weight">(\d+)g</td>!si;
-    ($data->{height})       = $html =~ m!<td>Height:</td>\s*<td>(\d+)mm</td>!si;
-    ($data->{width})        = $html =~ m!<td>Width:</td>\s*<td>(\d+)mm</td>!si;
-    ($data->{image})        = $html =~ m!<meta property="og:image"\s+content="([^"]+)"\s+/>!si;
+    ($data->{isbn13})      = $html =~ m!<meta property="book:isbn"\s+content="(\d+)"\s+/>!si;
+    ($data->{title})       = $html =~ m!<meta property="og:title"\s+content="([^"]+)"\s+/>!si;
+    ($data->{author})      = $html =~ m!<p class="product__author"[^>]*>\s*<a[^>]+>([^<]+)</a>!si;
+    ($data->{binding})     = $html =~ m!<p class="product__format">\s*<span itemprop="bookFormat" >([^<\(]+)!si;
+    ($data->{publisher})   = $html =~ m!<td>Publisher:</td>\s*<td itemprop="publisher"[^>]*>\s*<a[^>]+>\s*<span[^>]+>([^<]+)</span>\s*</a>!si;
+    ($data->{pubdate})     = $html =~ m!<td>Pub date:</td>\s*<td itemprop="datePublished"[^>]*>([^<]+)</td>!si;
+    ($data->{description}) = $html =~ m!<meta property="og:description"\s+content="([^"]+)"\s+/>!si;
+    ($data->{pages})       = $html =~ m!<td>Number of pages:</td>\s*<td itemprop="numberOfPages">(\d+)</td>!si;
+    ($data->{weight})      = $html =~ m!<td>Weight:</td>\s*<td(?: itemprop="weight")?>(\d+)g</td>!si;
+    ($data->{height})      = $html =~ m!<td>Height:</td>\s*<td>(\d+)mm</td>!si;
+    ($data->{width})       = $html =~ m!<td>Width:</td>\s*<td>(\d+)mm</td>!si;
+    ($data->{image})       = $html =~ m!<meta property="og:image"\s+content="([^"]+)"\s+/>!si;
 
     $data->{image}     =~ s!https:///!https://bookshop.blackwell.co.uk/!;
     $data->{thumb}     = $data->{image};
     $data->{isbn10}    = $isbn10;
+    $data->{author}    =~ s/\s*\(author\)//si;
     $data->{publisher} =~ s/&#0?39;/'/g;
 
 #use Data::Dumper;
 #print STDERR "\n# " . Dumper($data);
 
-	return $self->handler("Could not extract data from the Blackwell result page.")
-		unless(defined $data);
+    return $self->handler("Could not extract data from the Blackwell result page.")
+        unless(defined $data);
 
-	# trim top and tail
-	foreach (keys %$data) { 
+    # trim top and tail
+    foreach (keys %$data) { 
         next unless(defined $data->{$_});
         $data->{$_} =~ s!&nbsp;! !g;
         $data->{$_} =~ s/^\s+//;
@@ -150,32 +151,32 @@ sub search {
 
     my $url = $mech->uri();
 
-	my $bk = {
-		'ean13'		    => $data->{isbn13},
-		'isbn13'		=> $data->{isbn13},
-		'isbn10'		=> $data->{isbn10},
-		'isbn'			=> $data->{isbn13},
-		'author'		=> $data->{author},
-		'title'			=> $data->{title},
-		'book_link'		=> $url,
-		'image_link'	=> $data->{image},
-		'thumb_link'	=> $data->{thumb},
-		'description'	=> $data->{description},
-		'pubdate'		=> $data->{pubdate},
-		'publisher'		=> $data->{publisher},
-		'binding'	    => $data->{binding},
-		'pages'		    => $data->{pages},
-		'weight'		=> $data->{weight},
-		'height'		=> $data->{height},
-		'width'		    => $data->{width},
-	};
+    my $bk = {
+        'ean13'       => $data->{isbn13},
+        'isbn13'      => $data->{isbn13},
+        'isbn10'      => $data->{isbn10},
+        'isbn'        => $data->{isbn13},
+        'author'      => $data->{author},
+        'title'       => $data->{title},
+        'book_link'   => $url,
+        'image_link'  => $data->{image},
+        'thumb_link'  => $data->{thumb},
+        'description' => $data->{description},
+        'pubdate'     => $data->{pubdate},
+        'publisher'   => $data->{publisher},
+        'binding'     => $data->{binding},
+        'pages'       => $data->{pages},
+        'weight'      => $data->{weight},
+        'height'      => $data->{height},
+        'width'       => $data->{width},
+    };
 
 #use Data::Dumper;
 #print STDERR "\n# book=".Dumper($bk);
 
     $self->book($bk);
-	$self->found(1);
-	return $self->book;
+    $self->found(1);
+    return $self->book;
 }
 
 1;
@@ -214,7 +215,7 @@ be forthcoming, please feel free to (politely) remind me.
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2017 Barbie for Miss Barbell Productions
+  Copyright (C) 2010-2019 Barbie for Miss Barbell Productions
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
